# Sentiment Analysis

The `SentimentAnalysis` task determines the sentiment of the text (e.g., positive, negative, neutral).

## Usage

```python
--8<-- "sieves/tests/docs/test_task_usage.py:sentiment-usage"
```

---

::: sieves.tasks.predictive.sentiment_analysis.core
::: sieves.tasks.predictive.sentiment_analysis.bridges
